"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.createMasterEdition = exports.getCreateMasterEditionInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
const types_1 = require("../types");
function getCreateMasterEditionInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        [
            'createMasterEditionArgs',
            (0, types_1.getCreateMasterEditionArgsSerializer)(context),
        ],
    ], { description: 'CreateMasterEditionInstructionData' }), (value) => ({ ...value, discriminator: 10 }));
}
exports.getCreateMasterEditionInstructionDataSerializer = getCreateMasterEditionInstructionDataSerializer;
function createMasterEdition(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const mintAccount = input.mint;
    const editionAccount = input.edition ??
        (0, accounts_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const updateAuthorityAccount = input.updateAuthority ?? context.identity;
    const mintAuthorityAccount = input.mintAuthority;
    const payerAccount = input.payer ?? context.payer;
    const metadataAccount = input.metadata ??
        (0, accounts_1.findMetadataPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const rentAccount = input.rent ?? (0, umi_1.publicKey)('SysvarRent111111111111111111111111111111111');
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, true),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, true),
    });
    signers.push(updateAuthorityAccount);
    keys.push({
        pubkey: updateAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(updateAuthorityAccount, false),
    });
    signers.push(mintAuthorityAccount);
    keys.push({
        pubkey: mintAuthorityAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAuthorityAccount, false),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: rentAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(rentAccount, false),
    });
    const data = getCreateMasterEditionInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.createMasterEdition = createMasterEdition;
//# sourceMappingURL=createMasterEdition.js.map