"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.thawDelegatedAccount = exports.getThawDelegatedAccountInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
const accounts_1 = require("../accounts");
function getThawDelegatedAccountInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([['discriminator', s.u8()]], {
        description: 'ThawDelegatedAccountInstructionData',
    }), (value) => ({ ...value, discriminator: 27 }));
}
exports.getThawDelegatedAccountInstructionDataSerializer = getThawDelegatedAccountInstructionDataSerializer;
function thawDelegatedAccount(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const delegateAccount = input.delegate;
    const tokenAccountAccount = input.tokenAccount;
    const mintAccount = input.mint;
    const editionAccount = input.edition ??
        (0, accounts_1.findMasterEditionPda)(context, { mint: (0, umi_1.publicKey)(mintAccount) });
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    signers.push(delegateAccount);
    keys.push({
        pubkey: delegateAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(delegateAccount, true),
    });
    keys.push({
        pubkey: tokenAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenAccountAccount, true),
    });
    keys.push({
        pubkey: editionAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(editionAccount, false),
    });
    keys.push({
        pubkey: mintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(mintAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    const data = getThawDelegatedAccountInstructionDataSerializer(context).serialize({});
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.thawDelegatedAccount = thawDelegatedAccount;
//# sourceMappingURL=thawDelegatedAccount.js.map