"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.transferOutOfEscrow = exports.getTransferOutOfEscrowInstructionDataSerializer = void 0;
const umi_1 = require("@metaplex-foundation/umi");
function getTransferOutOfEscrowInstructionDataSerializer(context) {
    const s = context.serializer;
    return (0, umi_1.mapSerializer)(s.struct([
        ['discriminator', s.u8()],
        ['amount', s.u64()],
    ], { description: 'TransferOutOfEscrowInstructionData' }), (value) => ({ ...value, discriminator: 40 }));
}
exports.getTransferOutOfEscrowInstructionDataSerializer = getTransferOutOfEscrowInstructionDataSerializer;
function transferOutOfEscrow(context, input) {
    const signers = [];
    const keys = [];
    const programId = context.programs.getPublicKey('mplTokenMetadata', 'metaqbxxUerdq28cj1RbAWkYQm3ybzjb6a8bt518x1s');
    const escrowAccount = input.escrow;
    const metadataAccount = input.metadata;
    const payerAccount = input.payer ?? context.payer;
    const attributeMintAccount = input.attributeMint;
    const attributeSrcAccount = input.attributeSrc;
    const attributeDstAccount = input.attributeDst;
    const escrowMintAccount = input.escrowMint;
    const escrowAccountAccount = input.escrowAccount;
    const systemProgramAccount = input.systemProgram ?? {
        ...context.programs.getPublicKey('splSystem', '11111111111111111111111111111111'),
        isWritable: false,
    };
    const ataProgramAccount = input.ataProgram ?? {
        ...context.programs.getPublicKey('splAssociatedToken', 'ATokenGPvbdGVxr1b2hvZbsiqW5xWH25efTNsLJA8knL'),
        isWritable: false,
    };
    const tokenProgramAccount = input.tokenProgram ?? {
        ...context.programs.getPublicKey('splToken', 'TokenkegQfeZyiNwAJbNbGKPFXCWuBvf9Ss623VQ5DA'),
        isWritable: false,
    };
    const sysvarInstructionsAccount = input.sysvarInstructions ??
        (0, umi_1.publicKey)('Sysvar1nstructions1111111111111111111111111');
    const authorityAccount = input.authority;
    keys.push({
        pubkey: escrowAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowAccount, false),
    });
    keys.push({
        pubkey: metadataAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(metadataAccount, true),
    });
    signers.push(payerAccount);
    keys.push({
        pubkey: payerAccount.publicKey,
        isSigner: true,
        isWritable: (0, umi_1.checkForIsWritableOverride)(payerAccount, true),
    });
    keys.push({
        pubkey: attributeMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeMintAccount, false),
    });
    keys.push({
        pubkey: attributeSrcAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeSrcAccount, true),
    });
    keys.push({
        pubkey: attributeDstAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(attributeDstAccount, true),
    });
    keys.push({
        pubkey: escrowMintAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowMintAccount, false),
    });
    keys.push({
        pubkey: escrowAccountAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(escrowAccountAccount, false),
    });
    keys.push({
        pubkey: systemProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(systemProgramAccount, false),
    });
    keys.push({
        pubkey: ataProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(ataProgramAccount, false),
    });
    keys.push({
        pubkey: tokenProgramAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(tokenProgramAccount, false),
    });
    keys.push({
        pubkey: sysvarInstructionsAccount,
        isSigner: false,
        isWritable: (0, umi_1.checkForIsWritableOverride)(sysvarInstructionsAccount, false),
    });
    if (authorityAccount) {
        signers.push(authorityAccount);
        keys.push({
            pubkey: authorityAccount.publicKey,
            isSigner: true,
            isWritable: (0, umi_1.checkForIsWritableOverride)(authorityAccount, false),
        });
    }
    const data = getTransferOutOfEscrowInstructionDataSerializer(context).serialize(input);
    const bytesCreatedOnChain = 0;
    return (0, umi_1.transactionBuilder)([
        { instruction: { keys, programId, data }, signers, bytesCreatedOnChain },
    ]);
}
exports.transferOutOfEscrow = transferOutOfEscrow;
//# sourceMappingURL=transferOutOfEscrow.js.map